package entity

import (
	"time"
)

var editTime = time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC)
var deleteTime = time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC)
var checkedTime = time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC)

type PhotoMap map[string]Photo

func (m PhotoMap) Get(name string) Photo {
	if result, ok := m[name]; ok {
		return result
	}

	return Photo{PhotoName: name}
}

func (m PhotoMap) Pointer(name string) *Photo {
	if result, ok := m[name]; ok {
		return &result
	}

	return &Photo{PhotoName: name}
}

var PhotoFixtures = PhotoMap{
	"19800101_000002_D640C559": { //JPG, Imported, No Geo-information
		ID: 1000000,
		// UUID:
		PhotoUID:         "pt9jtdre2lvl0yh7",
		TakenAt:          time.Date(2008, 7, 1, 10, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(2008, 7, 1, 12, 0, 0, 0, time.UTC),
		TakenSrc:         "meta",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Lake / 2790",
		TitleSrc:         "",
		PhotoDescription: "photo description lake",
		DescriptionSrc:   "meta",
		PhotoPath:        "2790/07",
		PhotoName:        "27900704_070228_D6D51B6C",
		OriginalName:     "Vacation/exampleFileNameOriginal",
		PhotoFavorite:    false,
		//PhotoSingle
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        2790,
		PhotoMonth:       7,
		PhotoDay:         4,
		PhotoIso:         200,
		PhotoExposure:    "1/80",
		PhotoFNumber:     5,
		PhotoFocalLength: 50,
		PhotoQuality:     3,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "meta",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000000),
		Keywords: []Keyword{
			KeywordFixtures.Get("bridge"),
		},
		Albums: []Album{
			AlbumFixtures.Get("holiday-2030"),
		},
		Files: []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000000, "flower", 38, "image"),
			LabelFixtures.PhotoLabel(1000000, "cake", 38, "manual"),
		},
		CreatedAt:  time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 9,
		PhotoStack: 0,
		PhotoFaces: 3,
	},
	"Photo01": { //DNG + XMP,  Indexed, lat/lng manually set
		ID:               1000001,
		PhotoUID:         "pt9jtdre2lvl0yh8",
		TakenAt:          time.Date(2006, 1, 1, 2, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(2006, 1, 1, 2, 0, 0, 0, time.UTC),
		TakenSrc:         "meta",
		PhotoType:        "raw",
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "photo description blacklist",
		DescriptionSrc:   "",
		PhotoPath:        "2790/02",
		PhotoName:        "Photo01",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            PlaceFixtures.Pointer("Germany"),
		PlaceID:          PlaceFixtures.Pointer("Germany").ID,
		PlaceSrc:         "manual",
		Cell:             CellFixtures.Pointer("Neckarbrücke"),
		CellID:           CellFixtures.Pointer("Neckarbrücke").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     "de",
		PhotoYear:        2790,
		PhotoMonth:       2,
		PhotoDay:         12,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     3,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000001),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000001, "no-jpeg", 20, "image"),
		},
		CreatedAt:  time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2020, 3, 28, 14, 6, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 3,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"Photo02": { //JPG, Indexed, No Geo-information
		ID:               1000002,
		PhotoUID:         "pt9jtdre2lvl0yh9",
		TakenAt:          time.Date(1990, 3, 2, 0, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(1990, 3, 2, 0, 0, 0, 0, time.UTC),
		TakenSrc:         "manual",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "London",
		PhotoName:        "bridge1",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        1990,
		PhotoMonth:       3,
		PhotoDay:         2,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     3,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000002),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000002, "cake", 20, "image")},
		CreatedAt:        time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       12,
		PhotoStack:       0,
		PhotoFaces:       1,
	},
	"Photo03": { // JPG + JPG (same instance ID) + MP4, Indexed, Place from metadata
		ID:               1000003,
		PhotoUID:         "pt9jtdre2lvl0yh0",
		TakenAt:          time.Date(1990, 4, 18, 1, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(1990, 4, 18, 1, 0, 0, 0, time.UTC),
		TakenSrc:         "meta",
		PhotoType:        "video",
		PhotoDuration:    time.Hour * 2,
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "1990/04",
		PhotoName:        "bridge2",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        1990,
		PhotoMonth:       4,
		PhotoDay:         18,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     4,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("bridge", 1000003),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000003, "cow", 20, "image"),
			LabelFixtures.PhotoLabel(1000003, "updatePhotoLabel", 20, "manual"),
			LabelFixtures.PhotoLabel(1000000, "landscape", 10, "location"),
		},
		CreatedAt:  time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 12,
		PhotoStack: 0,
		PhotoFaces: 1,
	},
	"Photo04": { //JPG, Indexed, Place estimated
		ID:               1000004,
		PhotoUID:         "pt9jtdre2lvl0y11",
		TakenAt:          time.Date(2014, 7, 17, 15, 42, 12, 0, time.UTC),
		TakenAtLocal:     time.Date(2014, 7, 17, 17, 42, 12, 0, time.UTC),
		TakenSrc:         "meta",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Neckarbrücke",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "Germany",
		PhotoName:        "bridge",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            PlaceFixtures.Pointer("Germany"),
		PlaceID:          PlaceFixtures.Pointer("Germany").ID,
		PlaceSrc:         "estimate",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     PlaceFixtures.Pointer("Germany").CountryCode(),
		PhotoYear:        2014,
		PhotoMonth:       7,
		PhotoDay:         10,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     3,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000004),
		Keywords: []Keyword{
			KeywordFixtures.Get("bridge"),
			KeywordFixtures.Get("flower"),
		},
		Albums: []Album{
			AlbumFixtures.Get("berlin-2019"),
		},
		Files:      []File{},
		Labels:     []PhotoLabel{LabelFixtures.PhotoLabel(1000004, "batchdelete", 20, "image")},
		CreatedAt:  time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 12,
		PhotoStack: 0,
		PhotoFaces: 3,
	},
	"Photo05": { //JPG, Imported, File error, TakenAtSrc Name, titleSrc Name
		ID:               1000005,
		PhotoUID:         "pt9jtdre2lvl0y12",
		TakenAt:          time.Date(2015, 11, 1, 0, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(2015, 11, 1, 0, 0, 0, 0, time.UTC),
		TakenSrc:         "name",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Reunion",
		TitleSrc:         "name",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2015/11",
		PhotoName:        "20151101_000000_51C501B5",
		OriginalName:     "2015/11/reunion",
		PhotoFavorite:    false,
		PhotoPrivate:     true,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         -21.342636,
		PhotoLng:         55.466944,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2015,
		PhotoMonth:       11,
		PhotoDay:         0,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     3,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "123",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000005),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000005, "updateLabel", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       6,
		PhotoStack:       0,
		PhotoFaces:       2,
	},
	"Photo06": { // PNG + JPG, Private, Indexed
		ID:               1000006,
		PhotoUID:         "pt9jtdre2lvl0y13",
		TakenAt:          time.Date(2016, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "meta",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "ToBeUpdated",
		TitleSrc:         SrcMeta,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/11",
		PhotoName:        "Photo06",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     true,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         -21.342636,
		PhotoLng:         55.466944,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000006),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000006, "updatePhotoLabel", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       4,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo07": { // Heif, Hei.JPG, Indexed
		ID:               1000007,
		PhotoUID:         "pt9jtdre2lvl0y14",
		TakenAt:          time.Date(2016, 11, 12, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 11, 12, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "ToBeUpdated",
		TitleSrc:         SrcMeta,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/11",
		PhotoName:        "Photo07",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       11,
		PhotoDay:         12,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000007),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000007, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         &editTime,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       4,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo08": { // JPG, Indexed, Monochrome, Places meta
		ID:               1000008,
		PhotoUID:         "pt9jtdre2lvl0y15",
		TakenAt:          time.Date(2016, 11, 11, 8, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 11, 11, 8, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Black beach",
		TitleSrc:         SrcMeta,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/11",
		PhotoName:        "Photo08",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcManual,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         19.681944,
		PhotoLng:         -98.84659,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000008),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo09": { // jpg + jpg, stack sequential name, indexed
		ID:               1000009,
		PhotoUID:         "pt9jtdre2lvl0y16",
		TakenAt:          time.Date(2016, 11, 11, 8, 6, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 11, 11, 8, 6, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/11",
		PhotoName:        "Photo09",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         19.681944,
		PhotoLng:         -98.846590,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000009),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo10": { //mp4 + mp4 with error + jpg in sidecar, Indexed
		ID:               1000010,
		PhotoUID:         "pt9jtdre2lvl0y17",
		TakenAt:          time.Date(2016, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 11, 11, 11, 7, 18, 0, time.UTC),
		TakenSrc:         "manual",
		PhotoType:        "video",
		PhotoDuration:    time.Minute * 2,
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "Holiday",
		PhotoName:        "Video",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            PlaceFixtures.Pointer("holidaypark"),
		PlaceID:          PlaceFixtures.Pointer("holidaypark").ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("hassloch"),
		CellID:           CellFixtures.Pointer("hassloch").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         49.31,
		PhotoLng:         8.30,
		PhotoCountry:     PlaceFixtures.Pointer("holidaypark").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 10000010),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       9,
		PhotoStack:       0,
		PhotoFaces:       1,
	},
	"Photo11": { // JPG
		ID:               1000011,
		PhotoUID:         "pt9jtdre2lvl0y18",
		TakenAt:          time.Date(2016, 12, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 12, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/12",
		PhotoName:        "Photo11",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            PlaceFixtures.Pointer("emptyNameLongCity"),
		PlaceID:          PlaceFixtures.Pointer("emptyNameLongCity").ID,
		PlaceSrc:         "",
		Cell:             CellFixtures.Pointer("emptyNameLongCity"),
		CellID:           CellFixtures.Pointer("emptyNameLongCity").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     PlaceFixtures.Pointer("emptyNameLongCity").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       12,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 10000011),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       11,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo12": { //JPG
		ID:               1000012,
		PhotoUID:         "pt9jtdre2lvl0y19",
		TakenAt:          time.Date(2016, 01, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 01, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/01",
		PhotoName:        "Photo12",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            PlaceFixtures.Pointer("emptyNameShortCity"),
		PlaceID:          PlaceFixtures.Pointer("emptyNameShortCity").ID,
		PlaceSrc:         "",
		Cell:             CellFixtures.Pointer("emptyNameShortCity"),
		CellID:           CellFixtures.Pointer("emptyNameShortCity").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     PlaceFixtures.Pointer("emptyNameShortCity").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       1,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          &Details{},
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo13": { //JPG
		ID:               1000013,
		PhotoUID:         "pt9jtdre2lvl0y20",
		TakenAt:          time.Date(2016, 06, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2016, 06, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2016/06",
		PhotoName:        "Photo13",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("veryLongLocName"),
		PlaceID:          PlaceFixtures.Pointer("veryLongLocName").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("veryLongLocName"),
		CellID:           CellFixtures.Pointer("veryLongLocName").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         19.681944,
		PhotoLng:         -98.846590,
		PhotoCountry:     PlaceFixtures.Pointer("veryLongLocName").CountryCode(),
		PhotoYear:        2016,
		PhotoMonth:       6,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          &Details{},
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000008, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo14": { //JPG
		ID:               1000014,
		PhotoUID:         "pt9jtdre2lvl0y21",
		TakenAt:          time.Date(2018, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2018, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Title",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2018/11",
		PhotoName:        "Photo14",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mediumLongLocName"),
		PlaceID:          PlaceFixtures.Pointer("mediumLongLocName").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mediumLongLocName"),
		CellID:           CellFixtures.Pointer("mediumLongLocName").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         19.681944,
		PhotoLng:         -98.846590,
		PhotoCountry:     PlaceFixtures.Pointer("mediumLongLocName").CountryCode(),
		PhotoYear:        2018,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          &Details{},
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(1000014, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo15": { // JPG FileMissing = true, Indexed
		ID:               1000015,
		PhotoUID:         "pt9jtdre2lvl0y22",
		TakenAt:          time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcName,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "TitleToBeSet",
		TitleSrc:         SrcName,
		PhotoDescription: "photo description blacklist",
		DescriptionSrc:   SrcMeta,
		PhotoPath:        "1990",
		PhotoName:        "missing",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            PlaceFixtures.Pointer("Germany"),
		PlaceID:          PlaceFixtures.Pointer("Germany").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("Neckarbrücke"),
		CellID:           CellFixtures.Pointer("Neckarbrücke").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     "de",
		PhotoYear:        2013,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("blacklist", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(10000015, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       6,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo16": { //JPG
		ID:               1000016,
		PhotoUID:         "pt9jtdre2lvl0y23",
		TakenAt:          time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "ForDeletion",
		TitleSrc:         SrcName,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "1990",
		PhotoName:        "Photo16",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        true,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     UnknownCountry.ID,
		PhotoYear:        2013,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{LabelFixtures.PhotoLabel(10000015, "landscape", 20, "image")},
		CreatedAt:        time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo17": { // JPG, Indexed, Favorite, Quality 1, Places from metadata
		ID:               1000017,
		PhotoUID:         "pt9jtdre2lvl0y24",
		TakenAt:          time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Quality1FavoriteTrue",
		TitleSrc:         SrcName,
		PhotoDescription: "",
		DescriptionSrc:   SrcAuto,
		PhotoPath:        "1990/04",
		PhotoName:        "Quality1FavoriteTrue",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2013,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000015, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 6,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"Photo18": { // JPG, Indexed, Archived, Chroma 0
		ID:               1000018,
		PhotoUID:         "pt9jtdre2lvl0y25",
		TakenAt:          time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2013, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "ArchivedChroma0",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "Archived",
		PhotoName:        "Photo18",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2013,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     0,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2019, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  &deleteTime,
		PhotoColor: 9,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"Photo19": { // JPG, Indexed, Low Quality
		ID:               1000019,
		UUID:             "123e4567-e89b-12d3-a456-426614174000",
		PhotoUID:         "pt9jtxrexxvl0yh0",
		TakenAt:          time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "1990/04",
		PhotoName:        "Photo19",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        2008,
		PhotoMonth:       1,
		PhotoDay:         1,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     -1,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("bridge", 1000019),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{},
		CreatedAt:        time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2010, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       12,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo20": { // JPG
		ID:               1000020,
		PhotoUID:         "pt9jtxrexxvl0y20",
		TakenAt:          time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Time{},
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "1990/04",
		PhotoName:        "Photo20",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         "",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownPlace.CountryCode(),
		PhotoYear:        2008,
		PhotoMonth:       1,
		PhotoDay:         1,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     1,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("bridge", 1000019),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{},
		CreatedAt:        time.Date(2009, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2008, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       1,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo21": { // mp4 + mp4.jpg, Imported, Estimated Location
		ID:               1000021,
		PhotoUID:         "pt9jtxrexxvl0y21",
		TakenAt:          time.Date(2018, 1, 1, 0, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Time{},
		TakenSrc:         "",
		PhotoType:        "video",
		TypeSrc:          "",
		PhotoTitle:       "",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2018/01",
		PhotoName:        "20180101_130410_418COOO0",
		OriginalName:     "my-videos/IMG_88888",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "Europe/Berlin",
		Place:            PlaceFixtures.Pointer("Germany"),
		PlaceID:          PlaceFixtures.Pointer("Germany").ID,
		PlaceSrc:         "estimate",
		Cell:             &UnknownLocation,
		CellID:           UnknownLocation.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     PlaceFixtures.Pointer("Germany").CountryCode(),
		PhotoYear:        2018,
		PhotoMonth:       1,
		PhotoDay:         1,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     1,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("bridge", 1000019),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{},
		CreatedAt:        time.Date(2020, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       14,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo22": { // JPG + JPG (place&time stack)
		ID:               1000022,
		PhotoUID:         "pt9jtxrexxvl0y22",
		TakenAt:          time.Date(2001, 1, 1, 7, 0, 0, 0, time.UTC),
		TakenAtLocal:     time.Date(2001, 1, 1, 7, 0, 0, 0, time.UTC),
		TakenSrc:         "",
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Lake / 2001",
		TitleSrc:         "",
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "Mexico-With-Family",
		PhotoName:        "Photo22",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2001,
		PhotoMonth:       1,
		PhotoDay:         1,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     1,
		PhotoResolution:  2,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          &Details{},
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{},
		CreatedAt:        time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2010, 1, 1, 8, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       14,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
	"Photo23": { //JPG, Favorite
		ID:               1000023,
		PhotoUID:         "pt9jtdre2lvl0y43",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "ForMerge",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2020/vacation",
		PhotoName:        "PhotoMerge",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"Photo24": { // CR2 + JPG in Sidecar, Indexed
		ID:               1000024,
		PhotoUID:         "pt9jtdre2lvl0y44",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "raw",
		TypeSrc:          "",
		PhotoTitle:       "ForMerge2",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2020/vacation",
		PhotoName:        "PhotoMerge2",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"Photo25": { // JPG, Indexed, Photo edited, Panorama true, Unstacked
		ID:               1000025,
		PhotoUID:         "pt9jtdre2lvl0y45",
		TakenAt:          time.Date(2007, 1, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2007, 1, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "photowitheditedatdate",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2007/12",
		PhotoName:        "PhotoWithEditedAt",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    true,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        0,
		PhotoMonth:       0,
		PhotoDay:         4,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2007, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2007, 3, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   &editTime,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 12,
		PhotoStack: IsUnstacked,
		PhotoFaces: 0,
	},
	"Photo26": { // JPG, Indexed, Panorama, Unstacked
		ID:               1000026,
		PhotoUID:         "pt9jtdre2lvl0y90",
		TakenAt:          time.Date(2007, 1, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2007, 1, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "phototobebatchapproved",
		TitleSrc:         SrcAuto,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2007/12",
		PhotoName:        "PhotoWithEditedAt_2",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    true,
		TimeZone:         "America/Mexico_City",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         1.234,
		PhotoLng:         4.321,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2007,
		PhotoMonth:       1,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     1,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: IsUnstacked,
		PhotoFaces: 0,
	},
	"Photo27": { // live (mp4 + jpg)
		ID:               1000027,
		PhotoUID:         "pt9jtdre2lvl0y50",
		TakenAt:          time.Date(2000, 12, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2000, 12, 11, 4, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "live",
		TypeSrc:          "",
		PhotoTitle:       "phototobebatchapproved2",
		TitleSrc:         SrcName,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000/12",
		PhotoName:        "PhotoToBeBatchApproved2",
		OriginalName:     "",
		PhotoFavorite:    true,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico",
		Place:            PlaceFixtures.Pointer("mexico"),
		PlaceID:          PlaceFixtures.Pointer("mexico").ID,
		PlaceSrc:         SrcMeta,
		Cell:             CellFixtures.Pointer("mexico"),
		CellID:           CellFixtures.Pointer("mexico").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         19.682,
		PhotoLng:         -98.84,
		PhotoCountry:     PlaceFixtures.Pointer("mexico").CountryCode(),
		PhotoYear:        2000,
		PhotoMonth:       12,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFNumber:     0,
		PhotoFocalLength: 0,
		PhotoQuality:     1,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 12,
		PhotoStack: IsStackable,
		PhotoFaces: 3,
	},
	"PhotoTimeZone": {
		ID:               1000028,
		PhotoUID:         "pr2xmef3ki00x54g",
		TakenAt:          time.Date(2015, 5, 17, 23, 2, 46, 0, time.UTC),
		TakenAtLocal:     time.Date(2015, 5, 17, 23, 2, 46, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "Estimate / 2015",
		TitleSrc:         SrcName,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2015/05",
		PhotoName:        "Estimate",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         SrcAuto,
		Cell:             nil,
		CellID:           UnknownPlace.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownCountry.ID,
		PhotoYear:        2015,
		PhotoMonth:       5,
		PhotoDay:         17,
		PhotoIso:         100,
		PhotoExposure:    "1/50",
		PhotoFNumber:     2.6,
		PhotoFocalLength: 3,
		PhotoQuality:     3,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details: &Details{
			PhotoID:   1000028,
			CreatedAt: TimeStamp(),
			UpdatedAt: TimeStamp(),
		},
		Keywords: []Keyword{},
		Albums:   []Album{},
		Files:    []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:   time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:   time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:    nil,
		CheckedAt:   nil,
		EstimatedAt: nil,
		DeletedAt:   nil,
		PhotoColor:  12,
		PhotoStack:  IsStackable,
		PhotoFaces:  0,
	},
	"VideoTimeZone": {
		ID:               1000029,
		PhotoUID:         "pr2xu7myk7wrbk2u",
		TakenAt:          time.Date(2015, 5, 17, 17, 48, 46, 0, time.UTC),
		TakenAtLocal:     time.Date(2015, 5, 17, 17, 48, 46, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "video",
		TypeSrc:          "",
		PhotoTitle:       "Estimate / 2015",
		TitleSrc:         SrcName,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2015/05",
		PhotoName:        "Estimate",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "UTC",
		Place:            &UnknownPlace,
		PlaceID:          UnknownPlace.ID,
		PlaceSrc:         SrcAuto,
		Cell:             nil,
		CellID:           UnknownPlace.ID,
		CellAccuracy:     0,
		PhotoAltitude:    0,
		PhotoLat:         0,
		PhotoLng:         0,
		PhotoCountry:     UnknownCountry.ID,
		PhotoYear:        2015,
		PhotoMonth:       5,
		PhotoDay:         17,
		PhotoIso:         100,
		PhotoExposure:    "",
		PhotoFNumber:     2.6,
		PhotoFocalLength: 3,
		PhotoQuality:     3,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details: &Details{
			PhotoID:   1000029,
			CreatedAt: TimeStamp(),
			UpdatedAt: TimeStamp(),
		},
		Keywords: []Keyword{},
		Albums:   []Album{},
		Files:    []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000018, "landscape", 20, "image"),
			LabelFixtures.PhotoLabel(10000018, "likeLabel", 20, "image")},
		CreatedAt:   time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:   time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:    nil,
		CheckedAt:   nil,
		EstimatedAt: nil,
		DeletedAt:   nil,
		PhotoColor:  12,
		PhotoStack:  IsStackable,
		PhotoFaces:  0,
	},
	"%photo28": { //JPG, Geo from metadata, indexed
		ID:               10000029,
		PhotoUID:         "pr2xu7myk7wrbk21",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "%Salad",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "%abc/%folderx",
		PhotoName:        "%photo28",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("%toss"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(10000029, "%tennis", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo29%": { //JPG, Geo from metadata, indexed
		ID:               1000030,
		PhotoUID:         "pr2xu7myk7wrbk22",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "cloud%",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "abc%/folde%",
		PhotoName:        "photo29%",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("magic%"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000030, "cell%", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo%30": { //JPG, Geo from metadata, indexed
		ID:               1000031,
		PhotoUID:         "pr2xu7myk7wrbk23",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "hon%ey",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "ab%c/fol%de",
		PhotoName:        "photo%30",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("ca%t"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000031, "chem%stry", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"&photo31": { //JPG, Geo from metadata, indexed
		ID:               1000032,
		PhotoUID:         "pr2xu7myk7wrbk24",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "&dad",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "&abc/&folde",
		PhotoName:        "&photo31",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("&hogwarts"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "&friendship", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo&32": { //JPG, Geo from metadata, indexed
		ID:               1000033,
		PhotoUID:         "pr2xu7myk7wrbk25",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "leader&ship",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "tes&r/lo&c",
		PhotoName:        "photo&32",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("love&trust"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "construction&failure", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo33&": { //JPG, Geo from metadata, indexed
		ID:               1000034,
		PhotoUID:         "pr2xu7myk7wrbk26",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "mom&",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2020&/vacation&",
		PhotoName:        "photo33&",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("countryside&"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "goal&", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"'photo34": { //JPG, Geo from metadata, indexed
		ID:               1000035,
		PhotoUID:         "pr2xu7myk7wrbk27",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "'poetry'",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "'2020/'vacation",
		PhotoName:        "'photo34",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("'grandfather"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "'activity", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo'35": { //JPG, Geo from metadata, indexed
		ID:               1000036,
		PhotoUID:         "pr2xu7myk7wrbk28",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "amaz'ing",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "20'20/vacat'ion",
		PhotoName:        "photo'35",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       12,
		PhotoDay:         17,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("apple-iphone-se"),
		CameraID:         CameraFixtures.Pointer("apple-iphone-se").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("4.15mm-f/2.2"),
		LensID:           LensFixtures.Pointer("4.15mm-f/2.2").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("grandma's"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "funera'l", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo36'": { //JPG, Geo from metadata, indexed
		ID:               1000037,
		PhotoUID:         "pr2xu7myk7wrbk29",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "pollution'",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2020'/vacation'",
		PhotoName:        "photo36'",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("apple-iphone-7"),
		CameraID:         CameraFixtures.Pointer("apple-iphone-7").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("cheescake'"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "technology'", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"*photo37": { //JPG, Geo from metadata, indexed
		ID:               1000038,
		PhotoUID:         "pr2xu7myk7wrbk30",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "*area",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "*2020/*vacation",
		PhotoName:        "*photo37",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("*rating"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "*tea", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo*38": { //JPG, Geo from metadata, indexed
		ID:               1000039,
		PhotoUID:         "pr2xu7myk7wrbk31",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "farm*animal",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "202*3/vac*ation",
		PhotoName:        "photo*38",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("three*four"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "soup*menu", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo39*": { //JPG, Geo from metadata, indexed
		ID:               1000040,
		PhotoUID:         "pr2xu7myk7wrbk32",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "engine*",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2023*/vacatio*",
		PhotoName:        "photo39*",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("tree*"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "proposal*", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"|photo40": { //JPG, Geo from metadata, indexed
		ID:               1000041,
		PhotoUID:         "pr2xu7myk7wrbk33",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "|football",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "|202/|vacation",
		PhotoName:        "|photo40",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("|mystery"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "|college", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo|41": { //JPG, Geo from metadata, indexed
		ID:               1000042,
		PhotoUID:         "pr2xu7myk7wrbk34",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "pain|ting",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "20|22/vacat|ion",
		PhotoName:        "photo|41",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("run|stay"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "potato|couch", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo42|": { //JPG, Geo from metadata, indexed
		ID:               1000043,
		PhotoUID:         "pr2xu7myk7wrbk35",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "supermarket|",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2022|/vacation|",
		PhotoName:        "photo42|",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("pillow|"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "mall|", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"43photo": { //JPG, Geo from metadata, indexed
		ID:               1000044,
		PhotoUID:         "pr2xu7myk7wrbk36",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "123community",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000/holiday",
		PhotoName:        "43photo",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("1dish"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "2020-world", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"pho44to": { //JPG, Geo from metadata, indexed
		ID:               1000045,
		PhotoUID:         "pr2xu7myk7wrbk37",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "cli44mate",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000/02",
		PhotoName:        "pho44to",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("nothing4you"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "sport-2021-event", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo45": { //JPG, Geo from metadata, indexed
		ID:               1000046,
		PhotoUID:         "pr2xu7myk7wrbk38",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "guest456",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000/02",
		PhotoName:        "photo45",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("joyx2"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "oven-3000", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"\"photo46": { //JPG, Geo from metadata, indexed
		ID:               1000047,
		PhotoUID:         "pr2xu7myk7wrbk39",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "\"member",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "\"2000/\"02",
		PhotoName:        "\"photo46",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("\"electronics"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "\"king", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo\"47": { //JPG, Geo from metadata, indexed
		ID:               1000048,
		PhotoUID:         "pr2xu7myk7wrbk40",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "sol\"ution",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "20\"00/0\"2",
		PhotoName:        "photo\"47",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("sal\"mon"),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "town\"ship", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo48\"": { //JPG, Geo from metadata, indexed
		ID:               1000049,
		PhotoUID:         "pr2xu7myk7wrbk41",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "desk\"",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000\"/02\"",
		PhotoName:        "photo48\"",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("fish\""),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "ladder\"", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	" photo49": { //JPG, Geo from metadata, indexed
		ID:               1000050,
		PhotoUID:         "pr2xu7myk7wrbk42",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       " chair",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        " 2000/ 02",
		PhotoName:        " photo49",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("fish\""),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "ladder\"", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo 50": { //JPG, Geo from metadata, indexed
		ID:               1000051,
		PhotoUID:         "pr2xu7myk7wrbk43",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "air craft",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "20 00/ 0 2",
		PhotoName:        "photo 50",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("fish\""),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "ladder\"", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo51 ": { //JPG, Geo from metadata, indexed
		ID:               1000052,
		PhotoUID:         "pr2xu7myk7wrbk44",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "image",
		TypeSrc:          "",
		PhotoTitle:       "love ",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2000 /02 ",
		PhotoName:        "photo51 ",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords: []Keyword{
			KeywordFixtures.Get("fish\""),
		},
		Albums: []Album{},
		Files:  []File{},
		Labels: []PhotoLabel{
			LabelFixtures.PhotoLabel(1000032, "ladder\"", 20, "image"),
		},
		CreatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:  time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:   nil,
		CheckedAt:  &checkedTime,
		DeletedAt:  nil,
		PhotoColor: 14,
		PhotoStack: 0,
		PhotoFaces: 0,
	},
	"photo52": { //GIF + JPG, Geo from metadata, indexed
		ID:               1000053,
		PhotoUID:         "pr2xu7myk7wrbk45",
		TakenAt:          time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenAtLocal:     time.Date(2020, 11, 11, 9, 7, 18, 0, time.UTC),
		TakenSrc:         SrcMeta,
		PhotoType:        "animated",
		TypeSrc:          "",
		PhotoTitle:       "My pretty animated GIF",
		TitleSrc:         SrcManual,
		PhotoDescription: "",
		DescriptionSrc:   "",
		PhotoPath:        "2020/GIF",
		PhotoName:        "photo52",
		OriginalName:     "",
		PhotoFavorite:    false,
		PhotoPrivate:     false,
		PhotoScan:        false,
		PhotoPanorama:    false,
		TimeZone:         "America/Mexico_City",
		Place:            CellFixtures.Pointer("caravan park").Place,
		PlaceID:          CellFixtures.Pointer("caravan park").Place.ID,
		PlaceSrc:         "meta",
		Cell:             CellFixtures.Pointer("caravan park"),
		CellID:           CellFixtures.Pointer("caravan park").ID,
		CellAccuracy:     0,
		PhotoAltitude:    3,
		PhotoLat:         48.519234,
		PhotoLng:         9.057997,
		PhotoCountry:     CellFixtures.Pointer("caravan park").Place.CountryCode(),
		PhotoYear:        2020,
		PhotoMonth:       11,
		PhotoDay:         11,
		PhotoIso:         0,
		PhotoExposure:    "",
		PhotoFocalLength: 0,
		PhotoFNumber:     0,
		PhotoQuality:     5,
		PhotoResolution:  0,
		Camera:           CameraFixtures.Pointer("canon-eos-6d"),
		CameraID:         CameraFixtures.Pointer("canon-eos-6d").ID,
		CameraSerial:     "",
		CameraSrc:        "",
		Lens:             LensFixtures.Pointer("lens-f-380"),
		LensID:           LensFixtures.Pointer("lens-f-380").ID,
		Details:          DetailsFixtures.Pointer("lake", 1000015),
		Keywords:         []Keyword{},
		Albums:           []Album{},
		Files:            []File{},
		Labels:           []PhotoLabel{},
		CreatedAt:        time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		UpdatedAt:        time.Date(2021, 1, 1, 0, 0, 0, 0, time.UTC),
		EditedAt:         nil,
		CheckedAt:        &checkedTime,
		DeletedAt:        nil,
		PhotoColor:       14,
		PhotoStack:       0,
		PhotoFaces:       0,
	},
}

// CreatePhotoFixtures inserts known entities into the database for testing.
func CreatePhotoFixtures() {
	for _, entity := range PhotoFixtures {
		Db().Create(&entity)
	}
}
